@@ -14,8 +14,8 @@ use Sys::Syslog;
 use Errorlog::TeeOutput;
 
 
-my $version ='$Id: Errorlog.pm 24757 2008-05-30 10:44:29Z anton $ ';
-our $VERSION="1.25";
+my $version ='$Id: Errorlog.pm 25638 2008-09-22 15:24:38Z anton $ ';
+our $VERSION="1.27";
 #global variable, needed for TeeOutput
 our $SELF;
 
@@ -185,8 +185,8 @@ sub new
   $SELF=$self;
 
   openTee (*STDERR,@params,\%params);
-  carp "Entering logmode for: $0 " if (verbosity() >=2 );
-  carp ("configdir: $self->{fields}->{configdir}");
+  carp "Entering logmode for: $0 " if ($Baseobject::verbosity >=2 );
+  carp ("configdir: $self->{fields}->{configdir}") if ($Baseobject::verbosity >=2 );
 
   return $self;
 }
@@ -273,7 +273,9 @@ sub teecallback
 #	$substr.="\n" unless ($substr =~ /\n/);
 #	next if ($substr =~ /^\W*$/);
 #       syslog $priority, $format, @args
-#           If $priority permits, logs ($format, @args) printed as by "printf(3V)", with the addition that %m is replaced with "$!" (the latest error message).
+#           If $priority permits, logs ($format, @args) printed as by "printf(3V)",
+#           with the addition that %m is replaced with "$!" (the latest error message).
+#
 	my $blocksize=$SELF->{fields}->{syslogmaxbuf};
 
 	if (length ($substr) > $blocksize)
@@ -312,7 +314,7 @@ sub teecallback
   elsif ($fh eq 'logbuffer')
   {
     $longmess=Errorlog::presentstackframe() if ($Baseobject::verbosity >= 3);
-    $SELF->{fields}->{logbuffer}.="@string$longmess";
+    $SELF->{fields}->{logbuffer}.=$SELF->leadingstring($fh)."@string$longmess";
   }
   else
   {
@@ -392,9 +394,9 @@ sub DESTROY
 sub leadingstring
 {
   my $self=shift;
+  my $fh=shift;
   return "" unless  ($self->field('marknewrun') );
 
-  my $fh=shift;
   my $delim=' -- ';
   my $pid="";
   $pid="\n[$$] "  unless ($fh eq 'syslog');
@@ -429,9 +431,8 @@ sub mail
 {
   my $self=shift;
   my $string=join ("\n",@_);
-
   warn "Sending mail to: $self->{fields}->{mailto}" ;
-  $self->debug ("using mailprog: $self->{fields}->{mailprogram}");
+  carp "using mailprog: $self->{fields}->{mailprogram}" if ($Baseobject::verbosity >=2 );
 
   unless ($self->{fields}->{mailto})
   {
@@ -542,7 +543,7 @@ sub overrule
     {
       $configfile="$configdir/${basepart}_errorlog.cf";
       next unless ( -r $configfile );
-      $self->debug( "found configfile: $configfile\n");
+      carp "Found configfile: $configfile" if ($Baseobject::verbosity >=2 );
 
       unless (open ($fh,$configfile) )
       {
@@ -595,7 +596,7 @@ sub overrule
 	  warn "ignoring variable: $name: type \"$ref\" not (yet:) supported";
 	}
       }
-      carp "Errorlog: Using configfile: $configfile\n" if ((verbosity > 1) or $self->error());
+      carp "Errorlog: Using configfile: $configfile\n" if (($Baseobject::verbosity > 1) or $self->error());
     }
   }
   else
@@ -653,7 +654,7 @@ redirected, which is probably what you want.
 
 Depending on context each flow of a program's output is optionally
 preceeded by a header, showing the name of the program, a timestamp,
-and environment variables: $REMOTE_USER, $REMOTE_ADDRESS.
+and environment variables: $REMOTE_USER, $REMOTE_ADDR.
 
 Depending on context each original output line is preceeded by a PID
 hostname and fullpath programname.
